/****************************************************************************************/
/*																						*/
/*							Automatic Tour Into the Picture (ATIP)						*/
/*																						*/
/****************************************************************************************/

//! \file	atip_tip_maker.h
//! \author	BOULANGER Kevin
//! \date	02nd August 2004
//! \brief	Compute the TIP parameters (vertices, textures) from a calibrated camera


#ifndef _ATIP_TIP_MAKER_H_
#define _ATIP_TIP_MAKER_H_

#include <atip.h>


//! Given the camera parameters, compute the vertices coordinates of the TIP
//! background polygons
//! \note Each TIP polygon has texture coordinates (0.0f, 0.0f), (1.0f, 0.0f),
//!       (1.0f, 1.0f), (0.0f, 1.0f)
//! \param atipData Reference to a ATIPdata structure which will be modified
//!                 (vertices and indices arrays)
void atipVerticesCoords(ATIPdata & atipData);

//! Given the vertices and other parameters, compute the textures for the
//! TIP polygons
//! \param textures Array of 5 image pointers representing the textures
//!                 (coded in 24 bits). The images are allocated by the function
//! \param image Original image
//! \param rotVertices Array of 8 vertices (x, y, z) defining the vertices of the
//!					   5 TIP polygons (rotated version)
//! \param indices Array of 5 quadruplets (v0, v1, v2, v3) containing the indices
//!                of the vertices to use for each TIP polygon
//! \param focal Focal length of the camera
//! \return True if there was no error, else call atipGetError()
bool atipComputeTextures(ATIPimage * textures[5], ATIPimage & image,
						 const float rotVertices[24], const unsigned int indices[20],
						 float focal);


#endif	// _ATIP_TIP_MAKER_H_