/****************************************************************************************/
/*																						*/
/*							Automatic Tour Into the Picture (ATIP)						*/
/*																						*/
/****************************************************************************************/

//! \file	atip_primitives.h
//! \author	BOULANGER Kevin
//! \date	01st July 2004
//! \brief	Drawing primitives for images (lines, ...)


#ifndef _ATIP_PRIMITIVES_H_
#define _ATIP_PRIMITIVES_H_


//! Draw a segment in a 8 bits image
//! \note (0,0) is the top left of the image
//! \param image in which the line is drawn
//! \param width Width of the image in pixels
//! \param height Height of the image in pixels
//! \param x0 X coordinate of the first end point
//! \param y0 Y coordinate of the first end point
//! \param x1 X coordinate of the second end point
//! \param y1 Y coordinate of the second end point
//! \param color Color of the line
void atipDrawSegment8(unsigned char * image, unsigned int width, unsigned int height,
					  unsigned int x0, unsigned int y0,
					  unsigned int x1, unsigned int y1,
					  unsigned char color);

//! Draw a segment in a 24 bits image
//! \note (0,0) is the top left of the image
//! \param image in which the line is drawn
//! \param width Width of the image in pixels
//! \param height Height of the image in pixels
//! \param x0 X coordinate of the first end point
//! \param y0 Y coordinate of the first end point
//! \param x1 X coordinate of the second end point
//! \param y1 Y coordinate of the second end point
//! \param red Red component of the color of the line
//! \param green Green component of the color of the line
//! \param blue Blue component of the color of the line
void atipDrawSegment24(unsigned char * image, unsigned int width, unsigned int height,
					   unsigned int x0, unsigned int y0,
					   unsigned int x1, unsigned int y1,
					   unsigned char red, unsigned char green, unsigned char blue);

#endif	// _ATIP_H_