/****************************************************************************************/
/*																						*/
/*							Automatic Tour Into the Picture (ATIP)						*/
/*																						*/
/****************************************************************************************/

//! \file	atip_camera_calib.h
//! \author	BOULANGER Kevin
//! \date	29th July 2004
//! \brief	Camera calibration from vanishing points


#ifndef _ATIP_CAMERA_CALIB_H_
#define _ATIP_CAMERA_CALIB_H_


//! Compute the camera parameters from a set of vanishing points
//! \param focal Resulting focal length (1 for the half of the image height)
//! \param fov Resulting field-of-view (in degrees)
//! \param rot Resulting rotation matrix (3x3) representing the rotation
//!            between the world and the camera coordinate systems
//! \param vanPoints Array of 3 quadruplets (x, y, phi, theta), one per
//!                  vanishing point. If the point is finite, (x, y) are the coordinates
//!                  of the point inside the image ; if the point is infinite, it is the
//!                  unit direction vector. (phi, theta) are the
//!                  gaussian hemisphere coordinates
//! \param infiniteVanPoints Array of 3 booleans which are true if the corresponding
//!                          vanishing points are infinite
//! \param width Width of the original image in pixels
//! \param height Height of the original image in pixels
//! \return True if there was no error, else call atipGetError()
bool atipCalibrateCamera(float & focal, float & fov, float rot[9],
						 float vanPoints[12], bool infiniteVanPoints[3],
						 unsigned int width, unsigned int height);


#endif	// _ATIP_CAMERA_CALIB_H_