/****************************************************************************************/
/*																						*/
/*							Automatic Tour Into the Picture (ATIP)						*/
/*																						*/
/****************************************************************************************/

//! \file	atip_tools.cpp
//! \author	BOULANGER Kevin
//! \date	26th June 2004
//! \brief	Main tools for the "Automatic Tour Into the Picture" library (ATIP)


#include <atip_tools.h>
#include <tools/atip_private_tools.h>

#define WIN32_LEAN_AND_MEAN
#include <windows.h>

#include <stdio.h>
#include <stdlib.h>


ATIPerror atipGetError()
{
	ATIPerror error = atipGetLastError();
	atipSetError(ATIP_NO_ERROR);
	return error;
}

//----------------------------------------------------------------------------------------

void atipErrorMessage(ATIPerror error, char * errorMessage)
{
	switch (error)
	{
		case ATIP_INVALID_ARGUMENT:
			strcpy(errorMessage, "Invalid argument");
			break;

		case ATIP_INVALID_OPERATION:
			strcpy(errorMessage, "Invalid operation");
			break;

		case ATIP_FILE_READ_ERROR:
			strcpy(errorMessage, "Error when reading a file");
			break;

		case ATIP_FILE_WRITE_ERROR:
			strcpy(errorMessage, "Error when writing a file");
			break;

		case ATIP_BAD_FILE_FORMAT:
			strcpy(errorMessage, "Bad file format");
			break;

		case ATIP_NOT_ENOUGH_EDGE_LINES:
			strcpy(errorMessage, "Not enpigh edge lines detected");
			break;

		case ATIP_NO_FINITE_VAN_POINT:
			strcpy(errorMessage, "No finite vanishing point detected");
			break;

		case ATIP_NO_THREE_DIFFERENT_VAN_POINTS:
			strcpy(errorMessage, "Unable to find three different vanishing points");
			break;

		default:
			strcpy(errorMessage, "UNKNOWN ERROR");
	}
}

//----------------------------------------------------------------------------------------

#ifdef _DEBUG

void AssertionError(const char * expr, const char * sourceFile, int sourceLine)
{
#ifdef _WIN32

	// Remove the full path of the file name
	int c;
	for (c = (int)strlen(sourceFile) - 1; (c > 0) && (sourceFile[c] != '\\'); c--) { }
	if (sourceFile[c] == '\\') c++;

	// Display a message box
	char msg[512];
	sprintf(msg, "Assertion error in file %s at line %d :\n%s\n",
			sourceFile + c, sourceLine, expr);
	MessageBox(0, msg, "Assertion error", MB_OK | MB_ICONERROR);

#endif	// _WIN32

	exit(1);
}

#endif	// _DEBUG

//----------------------------------------------------------------------------------------

void OutOfMemoryError()
{
	MessageBox(0, "Out of memory error. The program is going to quit.",
			   "Out of memory", MB_OK | MB_ICONERROR | MB_SYSTEMMODAL);
	exit(1);
}

//----------------------------------------------------------------------------------------

void atipSetIntermediateResultsFlags(unsigned int intermResults)
{
	// In atip_private_tools.h
	atipSetIntermResultsFlags(intermResults);
}

//----------------------------------------------------------------------------------------

unsigned int atipGetIntermediateResultsFlags()
{
	// In atip_private_tools.h
	return atipGetIntermResultsFlags();
}

//----------------------------------------------------------------------------------------

void atipSetIntermediateResultCallback(ATIPintermediateResultProc proc)
{
	// In atip_private_tools.h
	atipSetIntermResultCallback(proc);
}

//----------------------------------------------------------------------------------------

void atipSetPercentageCallback(ATIPpercentageProc proc)
{
	// In atip_private_tools.h
	atipSetPercCallback(proc);
}
