/****************************************************************************************/
/*																						*/
/*							Automatic Tour Into the Picture (ATIP)						*/
/*																						*/
/****************************************************************************************/

//! \file	atip_private_tools.cpp
//! \author	BOULANGER Kevin
//! \date	27th June 2004
//! \brief	Private tools reserved for the ATIP implementation


#include <tools/atip_private_tools.h>


//! Code of the last error
ATIPerror lastError = ATIP_NO_ERROR;

//! Intermediate results flags
unsigned int intermResultsFlags = 0;

//! Intermediate result callback
ATIPintermediateResultProc intermResultCallback = 0;

//! Percentage callback
ATIPpercentageProc percentageCallback = 0;

//! Polygons editor
ATIPpolygonsEditorProc polygonsEditorCallback = 0;

//----------------------------------------------------------------------------------------

void atipSetError(ATIPerror error)
{
	lastError = error;
}

//----------------------------------------------------------------------------------------

ATIPerror atipGetLastError()
{
	return lastError;
}

//----------------------------------------------------------------------------------------

void atipSetIntermResultsFlags(unsigned int intermResults)
{
	intermResultsFlags = intermResults;
}

//----------------------------------------------------------------------------------------

bool atipIsIntermResultActive(unsigned int intermResult)
{
	return (intermResultsFlags & intermResult) != 0;
}

//----------------------------------------------------------------------------------------

unsigned int atipGetIntermResultsFlags()
{
	return intermResultsFlags;
}

//----------------------------------------------------------------------------------------

void atipSetIntermResultCallback(ATIPintermediateResultProc proc)
{
	intermResultCallback = proc;
}

//----------------------------------------------------------------------------------------

bool atipCallIntermResultCallback(const ATIPimage & image, const char * title)
{
	if (intermResultCallback)
			return (*intermResultCallback)(image, title);
	else	return true;
}

//----------------------------------------------------------------------------------------

void atipSetPercCallback(ATIPpercentageProc proc)
{
	percentageCallback = proc;
}

//----------------------------------------------------------------------------------------

void atipCallPercentageCallback(float percentage)
{
	if (percentageCallback)
		(*percentageCallback)(percentage);
}

//----------------------------------------------------------------------------------------

void atipSetPolyEdCallback(ATIPpolygonsEditorProc proc)
{
	polygonsEditorCallback = proc;
}

//----------------------------------------------------------------------------------------

bool atipCallPolygonsEditorCallback(ATIPdata & atipData, ATIPimage & origImage,
									unsigned int nFiniteVanPoints,
									unsigned int nInfiniteVanPoints)
{
	if (polygonsEditorCallback)
		(*polygonsEditorCallback)(atipData, origImage,
								  nFiniteVanPoints, nInfiniteVanPoints);
	else
	{
		atipSetError(ATIP_INVALID_OPERATION);
		return false;
	}
	return true;
}